erepublik package
=================

Submodules
----------

erepublik.citizen module
------------------------

.. automodule:: erepublik.citizen
   :members:
   :undoc-members:
   :show-inheritance:

erepublik.classes module
------------------------

.. automodule:: erepublik.classes
   :members:
   :undoc-members:
   :show-inheritance:

erepublik.utils module
----------------------

.. automodule:: erepublik.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: erepublik
   :members:
   :undoc-members:
   :show-inheritance:
